
import { Observable, Subject } from 'rxjs';
import { TransmitterProfile, ReceiverProfile, AdaptorTransmissionRole } from '../interface/connector.interface';
import { MessageTransmissionBase as MessageTransmissionBaseInterface } from '../interface/transport.interface'
import { v4 as uuidv4 } from 'uuid'

export class MessageTransmissionBase implements MessageTransmissionBaseInterface {
    transmitterProfile!: TransmitterProfile;
    receiverProfile!: ReceiverProfile;
    msgRepositoryService: any;
    transmissionRole!: AdaptorTransmissionRole;
    adaptorsArray!: any[];
    transmissionService: any;
    adapterService: any;
    incomingMessageBus!: Subject<any>;
    outgoingMessageBus!: Subject<any>;

    constructor() {
        this.setTransmitter({
            id: uuidv4(),
            name: 'Transmitter' + process.env.PORT,
            dateCreated: new Date()
        })
        this.setReceiver({
            id: uuidv4(),
            name: 'Receiver',
            dateCreated: new Date()
        })
    }

    // Pretty straight forward. Set itself straight away.
    setTransmitter(transmitterProfile: TransmitterProfile): void {
        this.transmitterProfile = transmitterProfile
    }

    setReceiver(receiverProfile: ReceiverProfile): Promise<any> {
        throw new Error('Method not implemented.');
    }

    send(message: any): Observable<any> {
        throw new Error('Method not implemented.');
    }
    emit(message: any): void {
        throw new Error('Method not implemented.');
    }
    emitStream(message: any): void {
        throw new Error('Method not implemented.');
    }
    subscribeMessages(messageFilter: any): Observable<any> {
        throw new Error('Method not implemented.');
    }

}